@@ -4,7 +4,7 @@ import os
 
 from dokuWikiDumper.utils.util import uopen
 
-configPath = 'dumpMeta/config.json'
+CONFIG_FILEPATH = 'dumpMeta/config.json'
 
 
 def update_config(dumpDir: str, config: dict):
@@ -13,13 +13,13 @@ def update_config(dumpDir: str, config: dict):
     config = {**_config, **config}
     print("Config: ", config)
 
-    with uopen(os.path.join(dumpDir, configPath), 'w') as f:
+    with uopen(os.path.join(dumpDir, CONFIG_FILEPATH), 'w') as f:
         json.dump(config, f, indent=4, ensure_ascii=False)
 
 
 def get_config(dumpDir: str) -> dict:
-    if os.path.exists(os.path.join(dumpDir, configPath)):
-        with uopen(os.path.join(dumpDir, configPath), 'r') as f:
+    if os.path.exists(os.path.join(dumpDir, CONFIG_FILEPATH)):
+        with uopen(os.path.join(dumpDir, CONFIG_FILEPATH), 'r') as f:
             _config = json.load(f)
             return _config
 
